@@ -35,9 +35,9 @@
 ;;; User options
 
 
-(defgroup speechd-speak nil
+(defgroup speechd-speak ()
   "Speechd-el user client customization."
-  :group 'speechd)
+  :group 'speechd-el)
 
 (defcustom speechd-speak-deleted-char t
   "If non-nil, speak the deleted char, otherwise speak the adjacent char."
@@ -146,7 +146,7 @@ and the keys are read after the command is performed."
   '(forward-char backward-char next-line previous-line
     delete-char delete-backward-char backward-delete-char-untabify)
   "List of commands for which their keys are never read."
-  :type '(repeat command)
+  :type '(repeat function)
   :group 'speechd-speak)
 
 (defcustom speechd-speak-read-command-name nil
@@ -1616,7 +1616,7 @@ When the mode is enabled, all spoken text is spelled."
 (defvar speechd-speak-spell-command nil)
 
 (defun speechd-speak-spell ()
-  "Let the very next command to be spell the text it reads."
+  "Let the very next command to spell the text it reads."
   (interactive)
   (unless speechd-speak-spell-mode
     (setq speechd-speak-spell-command t)))
